package Colecao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import oracle.jdbc.driver.OracleResultSet;
import Base.*;
import Excecoes.Excecao;

public class ColecaoPeca {

	private Connection con;

	public ColecaoPeca(Colecao col){
		this.con = col.getConexao();
		}
	
	public boolean existe(String peca_id)throws Excecao{
		boolean retorno = false;
		PreparedStatement stmt;
		OracleResultSet rset;
		try {
			stmt = con.prepareStatement("select * from peca_tab where peca_id = ?");
			stmt.setString(1, peca_id);
			rset = (OracleResultSet) stmt.executeQuery();
			retorno = rset.next();
			stmt.close();
		} catch (SQLException e){
			Excecao  excecao = new Excecao ("SQLException Metodo existe Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
		return retorno;
	}
	
	public void inserir(Peca peca)throws Excecao{
		PreparedStatement stmt;
		try {
			stmt = con.prepareStatement("insert into peca_tab values(?,?,?,?,?)");
			stmt.setString(1, peca.getId());
			stmt.setString(2, peca.getNome());
			stmt.setString(3, peca.getLocalizacao());
			stmt.setInt(4, peca.getQuantidade());
			stmt.setDouble(5, peca.getPreco());
			stmt.execute();
			stmt.close();
		} catch (SQLException e){
			Excecao  excecao = new Excecao ("SQLExecption  Metodo inserir Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
	}

	public void remover(String peca_id) throws Excecao{
		PreparedStatement stmt;
		try {
			stmt = con.prepareStatement("delete from peca_tab where peca_id = ?");
			stmt.setString(1, peca_id);
			stmt.execute();
			stmt.close();
		} catch (SQLException e) {
			Excecao  excecao = new Excecao ("SQLException Metodo remover Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
	}

	public void atualizar(Peca peca)throws Excecao {
		PreparedStatement stmt;
		try {
			stmt = con.prepareStatement("update peca_tab set nome = ?,localizacao = ?,quantidade = ?,preco = ? where peca_id = ?");
			stmt.setString(1, peca.getNome());
			stmt.setString(2, peca.getLocalizacao());
			stmt.setInt(3, peca.getQuantidade());
            stmt.setDouble(4, peca.getPreco());
            stmt.setString(5, peca.getId());
			stmt.execute();
			stmt.close();
		} catch (SQLException e) {
			Excecao  excecao = new Excecao ("SQLException Metodo atualizar Class ColecaoPeca\n" + e.getMessage());
			throw excecao;
		}
	}

	public Peca consulta(String id) throws Excecao {
		Peca peca;
		PreparedStatement stmt;		
		OracleResultSet rset;
		try {
			stmt = con.prepareStatement("select * from peca_tab where peca_id = ?");
			stmt.setString(1, id);
			rset = (OracleResultSet) stmt.executeQuery();
			rset.next();
			peca = new Peca(rset.getString("peca_id"),rset.getString("nome"),
			rset.getString("localizacao"),rset.getInt("quantidade"),rset.getDouble("preco"));
			stmt.close();
		} catch (SQLException e){
			Excecao  excecao = new Excecao ("SQLExecption  Metodo consulta Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
		return peca;
	}
	
	public void vender(String peca_id, String cliente_cnpj, int quantidade)throws Excecao{
		int quantidadeAnterior;
		double saldo, preco;
		PreparedStatement stmt1;
		OracleResultSet rset;
		try {
		
			stmt1 = con.prepareStatement("select quantidade from peca_tab where peca_id = ?");
			stmt1.setString(1, peca_id);
			rset = (OracleResultSet) stmt1.executeQuery();
			rset.next();
			quantidadeAnterior = rset.getInt("quantidade");
			stmt1.close();
			
			stmt1 = con.prepareStatement("update peca_tab set quantidade =  ? where peca_id = ?");
			stmt1.setInt(1, quantidadeAnterior-quantidade);
			stmt1.setString(2, peca_id);
                        stmt1.execute();
                        stmt1.close();

			stmt1 = con.prepareStatement("insert into vendas_tab values ((select count(*) from vendas_tab),?,?,?)");
			stmt1.setString(1, cliente_cnpj);
			stmt1.setString(2,peca_id);
			stmt1.setInt(3, quantidade);
			stmt1.execute();
			stmt1.close();
			System.out.print("depois de insert vendas");
                        
			stmt1 = con.prepareStatement("select saldo from saldo_tab where saldo_id = (select count(*) from saldo_tab)");
			rset = (OracleResultSet) stmt1.executeQuery();
			rset.next();
			saldo = rset.getDouble("saldo");
			stmt1.close();
			System.out.print("depois de select saldo");
			
                        stmt1 = con.prepareStatement("select preco from peca_tab where peca_id = ?");
			stmt1.setString(1, peca_id);
			rset = (OracleResultSet) stmt1.executeQuery();
			rset.next();
			preco = rset.getDouble("preco");
			stmt1.close();
			System.out.print("depois de select preco");
			
                        saldo = saldo + preco*quantidade;
			stmt1 = con.prepareStatement("insert into saldo_tab values ((( select count(*) from saldo_tab) + 1),((select count(*) from vendas_tab) - 1),?,?)");
			stmt1.setString(1,"v");
			stmt1.setDouble(2,saldo);
			stmt1.execute();
			stmt1.close();


		} catch (SQLException e){
			Excecao  excecao = new Excecao ("SQLExecption  Metodo vender Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
	}

	public void comprar(String peca_id, String fornecedor_cnpj, int quantidade, double preco)throws Excecao{
		int quantidadeAnterior; 
		PreparedStatement stmt1;
		OracleResultSet rset;
		double saldo;
                int saldoCurrval;
                int comprasCurrval;
		try {

			stmt1 = con.prepareStatement("select quantidade from peca_tab where peca_id = ?");
			stmt1.setString(1, peca_id);
			rset = (OracleResultSet) stmt1.executeQuery();
			rset.next();
			quantidadeAnterior = rset.getInt("quantidade");
			stmt1.close();
			
			stmt1 = con.prepareStatement("update peca_tab set quantidade =  ? where peca_id = ?");
			stmt1.setInt(1, quantidadeAnterior+quantidade);
			stmt1.setString(2, peca_id);
			stmt1.execute();
			stmt1.close();
			
                       
			stmt1 = con.prepareStatement("insert into compras_tab values ((select count(*) from compras_tab),?,?,?,?)");
			stmt1.setString(1, fornecedor_cnpj);
			stmt1.setString(2,peca_id);
			stmt1.setDouble(3,preco);
			stmt1.setInt(4, quantidade); 			  
			stmt1.execute();
			stmt1.close();
                        
              
			stmt1 = con.prepareStatement("select saldo from saldo_tab where saldo_id = (select count(*) from saldo_tab)");
                        rset = (OracleResultSet) stmt1.executeQuery();
			rset.next();
			saldo = rset.getDouble("saldo");
			saldo = saldo - preco*quantidade;
			stmt1.close();
		
                        
			stmt1 = con.prepareStatement("insert into saldo_tab values (((select count(*) from saldo_tab) + 1),((select count(*) from compras_tab) - 1),?,?)");
                        stmt1.setString(1,"c");
			stmt1.setDouble(2,saldo);
			stmt1.execute();
			stmt1.close();

		} catch (SQLException e){
			Excecao  excecao = new Excecao ("SQLExecption  Metodo comprar Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
	}
	
	public Compra[] consultarCompras() throws Excecao{
		PreparedStatement stmt;
        OracleResultSet rset;
        Compra[] retorno = null;
        int i = 0;
        try {
			stmt = con.prepareStatement("select count(*) as qtd from compras_tab");
			rset = (OracleResultSet) stmt.executeQuery();
	        rset.next();
	        retorno = new Compra[rset.getInt("qtd")];
	        stmt.close();
	        stmt = con.prepareStatement("select * from compras_tab");
	        rset = (OracleResultSet) stmt.executeQuery();
	        while(rset.next()){
	        	retorno[i] = new Compra(rset.getString("peca"),rset.getString("fornecedor"),rset.getInt("quantidade"),rset.getDouble("preco"));
	        	i++;
	        }
		} catch (SQLException e) {
			Excecao  excecao = new Excecao ("SQLExecption  Metodo consultarCompras Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
        return retorno;
	}
	public Venda[] consultarVendas() throws Excecao{
		PreparedStatement stmt;
        OracleResultSet rset;
        Venda[] retorno = null;
        int i = 0;
        try {
			stmt = con.prepareStatement("select count(*) as qtd from vendas_tab");
			rset = (OracleResultSet) stmt.executeQuery();
	        rset.next();
	        retorno = new Venda[rset.getInt("qtd")];
	        stmt.close();
	        stmt = con.prepareStatement("select * from vendas_tab");
	        rset = (OracleResultSet) stmt.executeQuery();
	        while(rset.next()){
	        	retorno[i] = new Venda(rset.getString("peca"),rset.getString("cliente"),rset.getInt("quantidade"));
	        	i++;
	        }
		} catch (SQLException e) {
			Excecao  excecao = new Excecao ("SQLExecption  Metodo consultarVendas Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
        return retorno;
	}
	
	public Saldo[] consultarSaldos() throws Excecao{
		PreparedStatement stmt;
        OracleResultSet rset;
        Saldo[] retorno = null;
        int i = 0;
        try {
			stmt = con.prepareStatement("select count(*) as qtd from saldo_tab");
			rset = (OracleResultSet) stmt.executeQuery();
	        rset.next();
	        retorno = new Saldo[rset.getInt("qtd")];
	        stmt.close();
	        stmt = con.prepareStatement("select * from saldo_tab");
	        rset = (OracleResultSet) stmt.executeQuery();
	        while(rset.next()){
	        	retorno[i] = new Saldo(rset.getString("id_transacao"),rset.getString("tipo_transacao"),rset.getDouble("saldo"));
	        	i++;
	        }
		} catch (SQLException e) {
			Excecao  excecao = new Excecao ("SQLExecption  Metodo consultarSaldos Class ColecaoPeca \n" + e.getMessage());
			throw excecao;
		}
        return retorno;
	}
}
