package Negocio;

import Base.Cliente;
import Base.Compra;
import Base.Fornecedor;
import Base.Peca;
import Base.Saldo;
import Base.Usuario;
import Base.Venda;
import Colecao.Colecao;
import Excecoes.Excecao;
import javax.swing.*;

public class Negocio {
	
	private Colecao colecao;
	private NegocioUsuario negocio_usuario;
	private NegocioCliente negocio_cliente;
	private NegocioFornecedor negocio_fornecedor;
	private NegocioPeca negocio_peca;
	
	
	public Negocio() throws Excecao{
		this.colecao = new Colecao();
		this.negocio_usuario = new NegocioUsuario(this.colecao);
		this.negocio_cliente = new NegocioCliente(this.colecao);
		this.negocio_fornecedor = new NegocioFornecedor(this.colecao);
		this.negocio_peca = new NegocioPeca(this.colecao);
	}
	public Negocio(NegocioCliente negocio_cliente, NegocioPeca negocio_peca,
			NegocioUsuario negocio_usuario, NegocioFornecedor negocio_fornecedor) {
		
		this.negocio_usuario = negocio_usuario;
		this.negocio_cliente = negocio_cliente;
		this.negocio_fornecedor = negocio_fornecedor;
		this.negocio_peca = negocio_peca;
	}
	public void efetuarLogin(String login, String senha) throws Excecao{
		this.negocio_usuario.efetuarLogin(login, senha);
	}
	public void cadastrarUsuario(String login, String senha, String nome, String cpf, String cidade, String bairro, String rua, String numero, String cep, String telefone,
		String data_nasc, int tipo) throws Excecao{
		this.negocio_usuario.cadastrarUsuario(login, senha, nome, cpf, cidade, bairro, rua, numero, cep, telefone,
				data_nasc, tipo);
	}
	public void removerUsuario(String cpf_cnpj) throws Excecao{
		this.negocio_usuario.removerUsuario(cpf_cnpj);
	}
	
	public void atualizarUsuario(String login, String senha, String nome, String cpf, String cidade, String bairro, String rua, String numero, String cep, String telefone,
			String data_nasc, int tipo) throws Excecao{
		this.negocio_usuario.atualizarUsuario(login, senha, nome, cpf, cidade, bairro, rua, numero, cep, telefone,
				data_nasc, tipo);
	}
	
	public Usuario consultarUsuario (String cpf) throws Excecao{
		return this.negocio_usuario.consultarUsuario(cpf);
	}
	
	public void cadastrarCliente(String nome, String cpf, String cidade, String bairro, String rua, String numero, String cep, String telefone,
		String data_nasc) throws Excecao {
		this.negocio_cliente.cadastrarCliente(nome, cpf, cidade, bairro, rua, numero, cep, telefone,
				data_nasc);
	}
	public void removerCliente(String cpf) throws Excecao{
		this.negocio_cliente.removerCliente(cpf);
	}
	
	public void atualizarCliente(String nome, String cpf, String cidade, String bairro, String rua, String numero, String cep, String telefone,
			String data_nasc) throws Excecao{
		this.negocio_cliente.atualizarCliente(nome, cpf, cidade, bairro, rua, numero, cep, telefone,
				data_nasc);
	}
	
	public Cliente consultarCliente(String cpf_cnpj) throws Excecao{
		return this.negocio_cliente.consultarCliente(cpf_cnpj);
	}
	
	public void cadastrarFornecedor(String nome, String cnpj, String cidade, String bairro, String rua, String numero, String cep, String telefone,
		String marca) throws Excecao{
		this.negocio_fornecedor.cadastrarFornecedor(nome, cnpj, cidade, bairro, rua, numero, cep, telefone,
				marca);
	}
	
	public void removerFornecedor(String cnpj) throws Excecao{
		this.negocio_fornecedor.removerFornecedor(cnpj);
	}
	
	public void atualizarFornecedor(String nome, String cnpj, String cidade, String bairro, String rua, String numero, String cep, String telefone,
			String marca) throws Excecao{
		this.negocio_fornecedor.atualizarFornecedor(nome, cnpj, cidade, bairro, rua, numero, cep, telefone,
				marca);
	}
	
	public Fornecedor consultarFornecedor(String cnpj) throws Excecao{
		return this.negocio_fornecedor.consultarFornecedor(cnpj);
	}

	
	public void cadastrarPeca(String id, String nome, String localizacao, int quantidade, double preco) throws Excecao{
		this.negocio_peca.cadastrarPeca(id, nome, localizacao, quantidade, preco);
	}

	public void removerPeca(String id) throws Excecao{
		this.negocio_peca.removerPeca(id);
	}

	public void atualizarPeca(String id, String nome, String localizacao, int quantidade, double preco) throws Excecao{
		this.negocio_peca.atualizarPeca(id, nome, localizacao, quantidade, preco);
	}
	
	public Peca consultarPeca(String id) throws Excecao{
		return this.negocio_peca.consultarPeca(id);
	}
	
	public void comprarPeca(String id, String cnpj, int quantidade,double preco) throws Excecao{
		if(this.negocio_fornecedor.existe(cnpj)){
                 this.negocio_peca.comprarPeca(id, cnpj, quantidade,preco);   
                }
                else{
                    throw new Excecao("Fornecedor nao existe.");
                }
                
	}
	public void venderPeca(String id, String cpf_cnpj, int quantidade) throws Excecao{
		if(this.negocio_cliente.existe(cpf_cnpj)){
                    this.negocio_peca.venderPeca(id, cpf_cnpj, quantidade);
                }
                else{
                    throw new Excecao("Cliente nao existe.");
                }
	}
	
	public Compra[] consultarCompras() throws Excecao{
		return this.negocio_peca.consultarCompras();
	}
	public Venda[] consultarVendas() throws Excecao{
		return this.negocio_peca.consultarVendas();
	}
	public Saldo[] consultarSaldos() throws Excecao{
		return this.negocio_peca.consultarSaldos();
	}
	
	public String[] gerarRelatorio() throws Excecao{
		
		Saldo[] saldos = this.consultarSaldos();
		Compra[] compras = this.consultarCompras();
		Venda[] vendas = this.consultarVendas();
		
		String[] extrato = new String[saldos.length - 1];
		String envolvido = "", op = "", id_envolvido = "", peca = "";
		int transacao = 0, quantidade = 0;
		double preco = 0;
		for(int i = 1; i < saldos.length; i++){
			if(saldos[i].getTipo_transacao().equals("c")){
				
				op = "Compra";
				envolvido = "FORNECEDOR:";
				transacao = Integer.parseInt(saldos[i].getId_transacao());
				id_envolvido = compras[transacao].get_fornecedor_cnpj();
				peca = compras[transacao].get_peca_id();
				quantidade = compras[transacao].get_quantidade();
				preco = compras[transacao].get_preco();
			}
			else if(saldos[i].getTipo_transacao().equals("v")){
				
				op = "Venda";
				envolvido = "CLIENTE:";
				transacao = Integer.parseInt(saldos[i].getId_transacao());
				id_envolvido = vendas[transacao].get_cliente_cpf_cnpj();
				peca = vendas[transacao].get_peca_id();
				quantidade = vendas[transacao].get_quantidade();
				preco = this.consultarPeca(peca).getPreco();
			}
			extrato[i - 1] = "OP: "+ op + "\nPECA: "+peca+" QTD: "+quantidade+" PRECO: "+preco+"\n"+envolvido+" "+id_envolvido+"\nSALDO: "+saldos[i].getSaldo()+"\n\n";
		}
		
		return extrato;
	}
	
	

	
}
